pub struct UnorderedBatch {
pub key_prefix_deletions: Vec<Vec<u8>>,
pub simple_unordered_batch: SimpleUnorderedBatch,
}Expand description
An unordered batch of deletions and insertions, together with a set of key-prefixes to delete.
The batch may contain collisions between key_prefix_deletions and insertions: a
prefix in key_prefix_deletions may cover one or more keys in insertions. Backends
are responsible for ordering execution so that insertions “happen after” the prefix
deletions semantically.
Fields
key_prefix_deletions: Vec<Vec<u8>>The key-prefix deletions.
simple_unordered_batch: SimpleUnorderedBatchThe batch of deletions and insertions.
Implementations
Sourceimpl UnorderedBatch
impl UnorderedBatch
Sourcepub async fn expand_delete_prefixes<DB: DeletePrefixExpander>(
self,
db: &DB,
) -> Result<SimpleUnorderedBatch, DB::Error>
pub async fn expand_delete_prefixes<DB: DeletePrefixExpander>( self, db: &DB, ) -> Result<SimpleUnorderedBatch, DB::Error>
From an UnorderedBatch, creates a SimpleUnorderedBatch that does not contain the
key_prefix_deletions. This requires accessing the database to eliminate them.